@@ -44,6 +44,19 @@ typedef m64p_error (*ptr_VidExt_Init)(void);
 EXPORT m64p_error CALL VidExt_Init(void);
 #endif
 
+/* VidExt_InitWithRenderMode()
+ *
+ * This function should be called from within the InitiateGFX() video plugin
+ * function call with the specified rendering mode (OpenGL or Vulkan).
+ * The default SDL implementation of this function simply calls
+ * SDL_InitSubSystem(SDL_INIT_VIDEO). It does not open a rendering window or
+ * switch video modes.
+ */
+typedef m64p_error (*ptr_VidExt_InitWithRenderMode)(m64p_render_mode);
+#if defined(M64P_CORE_PROTOTYPES)
+EXPORT m64p_error CALL VidExt_InitWithRenderMode(m64p_render_mode);
+#endif
+
 /* VidExt_Quit()
  *
  * This function closes any open rendering window and shuts down the video
@@ -67,6 +80,16 @@ typedef m64p_error (*ptr_VidExt_ListFullscreenModes)(m64p_2d_size *, int *);
 EXPORT m64p_error CALL VidExt_ListFullscreenModes(m64p_2d_size *, int *);
 #endif
 
+/* VidExt_ListFullscreenRates()
+ *
+ * This function is used to enumerate the available refresh rates for a fullscreen
+ * video mode.
+ */
+typedef m64p_error (*ptr_VidExt_ListFullscreenRates)(m64p_2d_size, int *, int *);
+#if defined(M64P_CORE_PROTOTYPES)
+EXPORT m64p_error CALL VidExt_ListFullscreenRates(m64p_2d_size, int *, int *);
+#endif
+
 /* VidExt_SetVideoMode()
  *
  * This function creates a rendering window or switches into a fullscreen
@@ -78,6 +101,17 @@ typedef m64p_error (*ptr_VidExt_SetVideoMode)(int, int, int, m64p_video_mode, m6
 EXPORT m64p_error CALL VidExt_SetVideoMode(int, int, int, m64p_video_mode, m64p_video_flags);
 #endif
 
+/* VidExt_SetVideoModeWithRate()
+ *
+ * This function creates a rendering window or switches into a fullscreen
+ * video mode. Any desired OpenGL attributes should be set before calling
+ * this function.
+ */
+typedef m64p_error (*ptr_VidExt_SetVideoModeWithRate)(int, int, int, int, m64p_video_mode, m64p_video_flags);
+#if defined(M64P_CORE_PROTOTYPES)
+EXPORT m64p_error CALL VidExt_SetVideoModeWithRate(int, int, int, int, m64p_video_mode, m64p_video_flags);
+#endif
+
 /* VidExt_ResizeWindow()
  *
  * This function resizes the opengl rendering window to match the given size.
@@ -160,6 +194,26 @@ typedef uint32_t (*ptr_VidExt_GL_GetDefaultFramebuffer)(void);
 EXPORT uint32_t CALL VidExt_GL_GetDefaultFramebuffer(void);
 #endif
 
+/* VidExt_VK_GetSurface()
+ *
+ * This functions gives out a vulkan surface
+ */
+typedef m64p_error (*ptr_VidExt_VK_GetSurface)(void**, void*);
+#if defined(M64P_CORE_PROTOTYPES)
+EXPORT m64p_error CALL VidExt_VK_GetSurface(void**, void*);
+#endif
+
+/* VidExt_VK_GetInstanceExtensions()
+ *
+ * This functions gives out a list of supported vulkan
+ * extensions, and the caller will be given the amount
+ * of strings stored in the list
+ */
+typedef m64p_error (*ptr_VidExt_VK_GetInstanceExtensions)(const char**[], uint32_t*);
+#if defined(M64P_CORE_PROTOTYPES)
+EXPORT m64p_error CALL VidExt_VK_GetInstanceExtensions(const char**[], uint32_t*);
+#endif
+
 #ifdef __cplusplus
 }
 #endif
